// Elements
const container = document.getElementById("container");
const zipCodeInput = document.getElementById("zipCode");
const billSlider = document.getElementById("billSlider");
const sliderValue = document.getElementById("sliderValue");
const homeAddressInput = document.getElementById("homeAddress");

// Slide Next Arrows
const arrow1 = document.getElementById("arrow-1");
const arrow2 = document.getElementById("arrow-2");
const arrow3 = document.getElementById("arrow-3");
const arrow4 = document.getElementById("arrow-4");
const arrow5 = document.getElementById("arrow-5");
const arrow6 = document.getElementById("arrow-6");
const arrow7 = document.getElementById("arrow-7");
const arrow8 = document.getElementById("arrow-8");

let currentSlide = 0;
let map, marker, autocomplete, geocoder;
let selectedCoordinates = { lat: 37.7749, lng: -122.4194 };
let formData = {};
let isValid = true;

// DOMContentLoaded
document.addEventListener("DOMContentLoaded", () => {
    // Reset slide on page load
    currentSlide = 0; // Reset slide index
    container.style.transform = `translateY(0)`; // Reset slide position
    document.body.classList.add("lock-scroll"); // Lock scroll on initial load
    console.log("Page loaded. Current slide reset to 0.");
    initMap(); // Initialize the map for Slide 5

    // Footer Mobile Menu Functionality (for mobile users)
    const footerMenuIcon = document.getElementById("footerMenuIcon");
    const footerMobileMenu = document.getElementById("footerMobileMenu");

    if (footerMenuIcon && footerMobileMenu) {
        footerMenuIcon.addEventListener("click", () => {
            footerMenuIcon.classList.toggle("open"); // Toggle the mobile menu
            if (footerMobileMenu.classList.contains("visible")) {
                footerMobileMenu.style.left = "-100%"; // Close the menu
                setTimeout(() => footerMobileMenu.classList.remove("visible"), 300);
            } else {
                footerMobileMenu.classList.add("visible"); // Open the menu
                footerMobileMenu.style.left = "0";
            }
        });
    } else {
        console.error("Footer menu elements not found in the DOM.");
    }

    // Capture UTM Parameters on Page Load (for tracking campaign data)
    formData.utmParameters = getUTMParameters();
    console.log("Captured UTM Parameters:", formData.utmParameters); // Debug log
});

// Generate a lead ID if it doesn't already exist
function generateLeadId() {
    return "_" + Math.random().toString(36).substr(2, 9); // Generates a lead ID based on a random string
}

// Function to parse UTM parameters from URL
function getUTMParameters() {
    const urlParams = new URLSearchParams(window.location.search);
    return {
        utm_source: urlParams.get("utm_source") || "",
        utm_medium: urlParams.get("utm_medium") || "",
        utm_campaign: urlParams.get("utm_campaign") || "",
        utm_content: urlParams.get("utm_content") || "",
        adgroup: urlParams.get("adgroup") || "",
        device: urlParams.get("device") || "",
        gclid: urlParams.get("gclid") || "",
        wbraid: urlParams.get("wbraid") || "",
        cacheBuster: urlParams.get("cacheBuster") || "",
        lpurl: urlParams.get("lpurl") || ""
    };
}

// Slide 1: Solar Only OR Solar Plus Battery
document.querySelectorAll(".equipment-card").forEach((card) => {
    card.addEventListener("click", () => {
        // Assign a Lead ID if it doesn't exist
        if (!formData.leadId) {
            formData.leadId = generateLeadId();
            console.log("Generated Lead ID:", formData.leadId); // Debug log
        }

        // Capture Equipment selection
        formData.equipment = card.getAttribute("data-equipment");
        console.log("Captured Equipment:", formData.equipment); // Debug log

        // Send incremental data for Slide 1 (equipment and UTM parameters)
        sendIncrementalData(1, { equipment: formData.equipment, utmParameters: formData.utmParameters });

        // Visually mark the selected card
        document.querySelectorAll(".equipment-card").forEach((c) => c.classList.remove("selected"));
        card.classList.add("selected");

        // Unlock scrolling and move to the next slide
        document.body.classList.remove("lock-scroll");
        moveToNextSlide();
    });
});

// Slide 2: ZIP Code Validation
zipCodeInput.addEventListener("input", () => {
    // Validate ZIP code format (must be exactly 5 digits)
    const isValidZip = /^\d{5}$/.test(zipCodeInput.value);
    // Enable/disable the next arrow based on validation
    arrow2.classList.toggle("disabled", !isValidZip);
});

arrow2.addEventListener("click", () => {
    // Check if the arrow is not disabled (valid ZIP code)
    if (!arrow2.classList.contains("disabled")) {
        formData.zipCode = zipCodeInput.value.trim(); // Capture the ZIP code
        console.log("Captured ZIP Code:", formData.zipCode); // Debug log

        // Send incremental data for Slide 2 (ZIP code)
        sendIncrementalData(2, { zipCode: formData.zipCode });

        // Use ZIP to geocode and adjust the map (if needed)
        narrowMapByZip(formData.zipCode);

        // Unlock scrolling and move to the next slide
        document.body.classList.remove("lock-scroll");
        moveToNextSlide();
    }
});

// Slide 3: Home Value Selection
document.querySelectorAll(".homeValue-card").forEach((card) => {
    card.addEventListener("click", () => {
        formData.homeValue = card.getAttribute("data-homeValue");
        console.log("Captured Home Value:", formData.homeValue); // Debug log

        // Redirect if "Less than $250K" is selected
        if (formData.homeValue === "Less Than 250K") {
            console.log("Redirecting due to disqualification...");
            window.location.href = "/dq/"; // Redirect to disqualification page
            return; // Stop further execution
        }

        // Send incremental data for Slide 3 (Home Value)
        sendIncrementalData(3, { homeValue: formData.homeValue });

        // Visually mark the selected card
        document.querySelectorAll(".homeValue-card").forEach((c) => c.classList.remove("selected"));
        card.classList.add("selected");

        // Unlock scrolling and move to the next slide
        document.body.classList.remove("lock-scroll");
        moveToNextSlide();
    });
});

// Slide 4: Bill Slider Input
billSlider.addEventListener("input", () => {
    sliderValue.textContent = `$${billSlider.value}`; // Update the displayed bill value
    arrow4.classList.remove("disabled"); // Enable arrow once value is set
});

arrow4.addEventListener("click", () => {
    // Send the captured bill data for Slide 4
    if (!arrow4.classList.contains("disabled")) {
        formData.bill = billSlider.value;
        console.log("Captured Bill:", formData.bill); // Debug log

        sendIncrementalData(4, { bill: formData.bill });

        document.body.classList.remove("lock-scroll");
        moveToNextSlide();
    }
});

// Slide 5: Validate Names (First and Last Name)
const firstNameInput = document.getElementById("firstName");
const lastNameInput = document.getElementById("lastName");

function validateNameInputs() {
    // Check if both names are filled out
    const isFirstNameValid = firstNameInput.value.trim() !== "";
    const isLastNameValid = lastNameInput.value.trim() !== "";
    arrow5.classList.toggle("disabled", !(isFirstNameValid && isLastNameValid)); // Enable/disable arrow
}

[firstNameInput, lastNameInput].forEach((input) => {
    input.addEventListener("input", validateNameInputs); // Add validation for name inputs
});

arrow5.addEventListener("click", () => {
    const first = firstNameInput.value.trim();
    const last = lastNameInput.value.trim();
    const firstNameError = document.getElementById("firstNameError");
    const lastNameError = document.getElementById("lastNameError");

    let isValid = true;

    // Validate first name
    if (!first) {
        firstNameError.textContent = "First name is required.";
        firstNameError.style.display = "block";
        isValid = false;
    } else {
        firstNameError.textContent = "";
        firstNameError.style.display = "none";
    }

    // Validate last name
    if (!last) {
        lastNameError.textContent = "Last name is required.";
        lastNameError.style.display = "block";
        isValid = false;
    } else {
        lastNameError.textContent = "";
        lastNameError.style.display = "none";
    }

    // If both names are valid, capture them and send incremental data
    if (isValid) {
        formData.firstName = first;
        formData.lastName = last;
        console.log("Captured Name:", formData.firstName, formData.lastName); // Debug log

        sendIncrementalData(5, { firstName: formData.firstName, lastName: formData.lastName });

        document.body.classList.remove("lock-scroll");
        moveToNextSlide();
    }
});

// Slide 6: Handle Address Input (Home Address)
homeAddressInput.addEventListener("input", () => {
    const isValidAddress = homeAddressInput.value.trim() !== ""; // Check if address is provided
    arrow6.classList.toggle("disabled", !isValidAddress); // Enable/disable the arrow
});

arrow6.addEventListener("click", () => {
    const address = homeAddressInput.value.trim();
    const addressError = document.getElementById("addressError");

    // Validate address
    if (!address) {
        addressError.textContent = "Address is required.";
        addressError.style.display = "block";
    } else {
        addressError.textContent = "";
        addressError.style.display = "none";

        formData.address = address; // Capture address
        console.log("Captured Address:", formData.address); // Debug log

        sendIncrementalData(6, { address: formData.address });

        document.body.classList.remove("lock-scroll");
        moveToNextSlide();
    }
});

// Slide 7: Are You The Primary Homeowner
const ownershipCards = document.querySelectorAll(".homeowner-card");

ownershipCards.forEach((card) => {
    card.addEventListener("click", () => {
        ownershipCards.forEach((c) => c.classList.remove("selected")); // Deselect all cards
        card.classList.add("selected"); // Select the clicked card

        formData.homeowner = card.getAttribute("data-ownership"); // Capture ownership status
        console.log("Captured Homeowner:", formData.homeowner); // Debug log

        if (formData.homeowner === "No") {
            console.log("Redirecting due to disqualification...");
            window.location.href = "/dq/"; // Redirect if not the primary homeowner
            return;
        }

        sendIncrementalData(7, { homeowner: formData.homeowner });

        document.body.classList.remove("lock-scroll");
        moveToNextSlide();
    });
});

// Slide 8: Email Validation
const emailInput = document.getElementById("emailInput");

emailInput.addEventListener("input", () => {
    const isValidEmail = /^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(emailInput.value); // Validate email format
    arrow8.classList.toggle("disabled", !isValidEmail); // Enable/disable the arrow based on validity
});

arrow8.addEventListener("click", () => {
    if (!arrow8.classList.contains("disabled")) {
        formData.email = emailInput.value.trim(); // Capture email
        console.log("Captured Email:", formData.email); // Debug log

        sendIncrementalData(8, { email: formData.email });

        document.body.classList.remove("lock-scroll");
        moveToNextSlide(); // Move to the next slide
    }
});

// Slide 9: Phone Validation and Final Submission Trigger
const phoneInput = document.getElementById("phoneInput");
const submitBtn = document.getElementById("submitBtn");

submitBtn.addEventListener("click", async () => {
    const phoneValue = phoneInput.value.trim();
    const phoneError = document.getElementById("phoneError");

    // Validate phone input (10 digits only)
    if (!/^\d{10}$/.test(phoneValue)) {
        phoneError.textContent = "Enter a valid 10-digit phone number.";
        phoneError.style.display = "block";
    } else {
        phoneError.textContent = "";
        phoneError.style.display = "none";

        // Capture phone number and add a timestamp to the formData
        formData.phone = phoneValue;
        formData.timestamp = new Date().toISOString();

        // Send the final submission data
        try {
            const result = await submitFinalForm(); // Call the final submission function
            if (result.success) {
                console.log("Final form submitted successfully.");

                // Redirect to the default Thank You page
                redirectToThankYouPage();
            } else {
                console.error("Final submission error:", result.message);
            }
        } catch (error) {
            console.error("Unexpected error during final form submission:", error);
        }
    }
});

// ✅ Function to redirect to the Thank You page
function redirectToThankYouPage() {
    const thankYouUrl = "/thank-you/";
    console.log("Redirecting to:", thankYouUrl);
    window.location.href = thankYouUrl;
}

// Function to handle the final form submission
async function submitFinalForm() {
    try {
        // Consolidate all data into the final submission object
        const finalData = {
            leadId: formData.leadId,
            phone: formData.phone,
            timestamp: formData.timestamp,
            submissions: collectedData, // Include incremental data
            utmParameters: formData.utmParameters // Include UTM parameters
        };

        // Send final data to save-to-json.php (local JSON file)
        const saveResponse = await fetch("save-to-json.php", {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify(finalData),
        });

        if (!saveResponse.ok) {
            throw new Error(`Failed to save data locally: ${saveResponse.statusText}`);
        }

        console.log("Final data successfully saved locally to submissions.json.");

        return { success: true }; // Return success if all operations succeed
    } catch (error) {
        console.error("Error during final form submission:", error);
        throw error; // Re-throw for external error handling
    }
}

// Function to send incremental data to save-to-json.php
async function sendIncrementalData(slideNumber, answer) {
    const incrementalData = {
        leadId: formData.leadId, // Reuse or assign a lead ID
        slide: slideNumber,
        answer: answer,
        timestamp: new Date().toISOString(), // Add a timestamp
    };

    // Include UTM parameters only for the first slide
    if (slideNumber === 1) {
        incrementalData.utmParameters = formData.utmParameters;
    }

    try {
        // Send incremental data to save-to-json.php
        const response = await fetch("save-to-json.php", {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify(incrementalData),
        });

        if (!response.ok) {
            console.error(`Failed to send data for Slide ${slideNumber}:`, response.statusText);
        } else {
            const result = await response.json();
            if (result.success) {
                console.log(`Slide ${slideNumber} data saved successfully.`);
                collectedData.push(incrementalData); // Save the incremental data locally
            } else {
                console.error(`Error saving data for Slide ${slideNumber}:`, result.message);
            }
        }
    } catch (error) {
        console.error("Error sending incremental data:", error);
    }
}

// Global collectedData array for incremental submissions
let collectedData = []; // Ensure incremental data is pushed here

// Initialize Google Maps and Autocomplete
function initMap() {
    geocoder = new google.maps.Geocoder(); // Initialize Geocoder
    map = new google.maps.Map(document.getElementById("map"), {
        center: selectedCoordinates,
        zoom: 15,
        mapTypeId: "satellite",
        tilt: 45,
        disableDefaultUI: true,
        zoomControl: true,
    });

    marker = new google.maps.Marker({
        position: selectedCoordinates,
        map: map,
        draggable: true,
        title: "Drag me to your roof!",
    });

    marker.addListener("dragend", () => {
        selectedCoordinates = marker.getPosition().toJSON();
        console.log("Updated Coordinates:", selectedCoordinates);
    });

    initAutocomplete(); // Initialize autocomplete
}

function initAutocomplete() {
    autocomplete = new google.maps.places.Autocomplete(homeAddressInput, {
        types: ["geocode"],
        componentRestrictions: { country: "us" },
    });

    autocomplete.addListener("place_changed", () => {
        const place = autocomplete.getPlace();

        if (!place.geometry || !place.geometry.location) {
            alert("No details available for the selected address.");
            return;
        }

        selectedCoordinates = {
            lat: place.geometry.location.lat(),
            lng: place.geometry.location.lng(),
        };

        map.setCenter(selectedCoordinates);
        map.setZoom(20);
        marker.setPosition(selectedCoordinates);

        console.log("Selected Place:", place);
        console.log("Coordinates:", selectedCoordinates);
    });
}

// Function to narrow map view using ZIP code
function narrowMapByZip(zip) {
    geocoder.geocode({ address: zip }, (results, status) => {
        if (status === "OK" && results[0].geometry) {
            const location = results[0].geometry.location;
            map.setCenter(location);
            marker.setPosition(location);
            selectedCoordinates = location.toJSON();
            console.log("Map narrowed to ZIP code:", zip, selectedCoordinates);
        } else {
            console.error("Geocoding failed for ZIP code:", status);
        }
    });
}

// Move Slides
function moveToNextSlide() {
    currentSlide++;
    container.style.transform = `translateY(-${currentSlide * 100}vh)`;
    if (currentSlide < document.querySelectorAll(".slide").length - 1) {
        document.body.classList.add("lock-scroll");
    } else {
        document.body.classList.remove("lock-scroll");
    }
}