<?php
// Paths to JSON files
$jsonFile = 'submissions.json';
$fullJsonFile = 'fullSubmissions.json';

// Get the JSON data sent by the client
$inputData = file_get_contents('php://input');

// Decode existing main submissions
$existingData = file_exists($jsonFile) ? json_decode(file_get_contents($jsonFile), true) : [];
$fullData = file_exists($fullJsonFile) ? json_decode(file_get_contents($fullJsonFile), true) : [];

// Process input
if ($inputData) {
    $newData = json_decode($inputData, true);

    if (!isset($newData['leadId'])) {
        echo json_encode(["success" => false, "message" => "Invalid input data. Missing leadId."]);
        exit;
    }

    $leadId = $newData['leadId'];
    $clientId = "CH-058";

    if (isset($newData['answer']['utmParameters'])) {
        $utmParameters = $newData['answer']['utmParameters'];
        unset($newData['answer']['utmParameters']);
    } else {
        $utmParameters = [];
    }

    $timestamp = $newData['timestamp'] ?? date("c");

    // 🔁 Update main submissions.json
    $found = false;
    foreach ($existingData as &$entry) {
        if ($entry['leadId'] === $leadId) {
            $found = true;
            if (!isset($entry['clientId'])) $entry['clientId'] = $clientId;
            if (!isset($entry['submissions'])) $entry['submissions'] = [];

            if (isset($newData['answer']['equipment'])) {
                $entry['submissions']['equipment'] = $newData['answer']['equipment'];
            }

            foreach ($newData['answer'] as $key => $value) {
                $entry['submissions'][$key] = $value;
            }

            if (!isset($entry['utmParameters']) || empty($entry['utmParameters'])) {
                $entry['utmParameters'] = $utmParameters;
            }

            if (isset($newData['phone'])) {
                $entry['submissions']['phone'] = preg_replace('/[^0-9]/', '', $newData['phone']);
            }

            break;
        }
    }

    if (!$found) {
        $newEntry = [
            'leadId' => $leadId,
            'clientId' => $clientId,
            'timestamp' => $timestamp,
            'submissions' => [],
            'utmParameters' => $utmParameters
        ];

        if (isset($newData['answer']['equipment'])) {
            $newEntry['submissions']['equipment'] = $newData['answer']['equipment'];
        }

        foreach ($newData['answer'] as $key => $value) {
            $newEntry['submissions'][$key] = $value;
        }

        if (isset($newData['phone'])) {
            $newEntry['submissions']['phone'] = preg_replace('/[^0-9]/', '', $newData['phone']);
        }

        $existingData[] = $newEntry;
    }

    // ✅ Save to submissions.json (with utmParameters)
    file_put_contents($jsonFile, json_encode($existingData, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES));

    // 🧠 Check if email or phone exists — then sync to fullSubmissions.json (WITHOUT utmParameters)
    $hasEmail = isset($newData['answer']['email']) && !empty($newData['answer']['email']);
    $hasPhone = isset($newData['phone']) && !empty($newData['phone']);

    if ($hasEmail || $hasPhone) {
        $foundFull = false;

        foreach ($fullData as &$entry) {
            if ($entry['leadId'] === $leadId) {
                $foundFull = true;

                foreach ($newData['answer'] as $key => $value) {
                    $entry['submissions'][$key] = $value;
                }

                if (isset($newData['phone'])) {
                    $entry['submissions']['phone'] = preg_replace('/[^0-9]/', '', $newData['phone']);
                }

                break;
            }
        }

        if (!$foundFull) {
            $newFullEntry = [
                'leadId' => $leadId,
                'clientId' => $clientId,
                'timestamp' => $timestamp,
                'submissions' => []
            ];

            foreach ($newData['answer'] as $key => $value) {
                $newFullEntry['submissions'][$key] = $value;
            }

            if (isset($newData['phone'])) {
                $newFullEntry['submissions']['phone'] = preg_replace('/[^0-9]/', '', $newData['phone']);
            }

            $fullData[] = $newFullEntry;
        }

        // 💾 Save to fullSubmissions.json
        file_put_contents($fullJsonFile, json_encode($fullData, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES));
    }

    echo json_encode(["success" => true, "message" => "Data saved successfully."]);
} else {
    echo json_encode(["success" => false, "message" => "No data received."]);
}
?>