import time
import os
import subprocess
from watchdog.observers import Observer
from watchdog.events import FileSystemEventHandler

# Path to watch
WATCHED_FILE = "submissions.json"
SCRIPT_TO_RUN = "python3 send_to_gsheet.py"

# ================================
# ✅ File Watcher Class
# ================================
class FileChangeHandler(FileSystemEventHandler):
    def on_modified(self, event):
        """Triggers when `submissions.json` is modified."""
        if event.src_path.endswith(WATCHED_FILE):
            print(f"📢 Detected change in {WATCHED_FILE}, updating Google Sheet...")
            subprocess.run(SCRIPT_TO_RUN, shell=True)

# ================================
# ✅ Function: Start Watching
# ================================
def start_watching():
    """Starts the watchdog observer to monitor file changes."""
    event_handler = FileChangeHandler()
    observer = Observer()
    observer.schedule(event_handler, path=os.path.dirname(os.path.abspath(WATCHED_FILE)), recursive=False)
    observer.start()
    print(f"👀 Watching {WATCHED_FILE} for changes...")

    try:
        while True:
            time.sleep(1)
    except KeyboardInterrupt:
        observer.stop()
    observer.join()

# Run the watcher
if __name__ == "__main__":
    start_watching()